==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/includes/ConfirmTab.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2013 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef CONFIRMWIDGET_H
#define CONFIRMWIDGET_H

#include <QWidget>
#include "ui_ConfirmTab.h"

class HTTraQt;

class ConfirmTab: public QWidget, public Ui_ConfirmTab
{
        Q_OBJECT
    public:
        ConfirmTab(QWidget *parent = 0, Qt::WFlags fl = 0);
        void translate();

    private:
        HTTraQt* parent;
};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/includes/ConfirmTab.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef CONFIRMWIDGET_H
#define CONFIRMWIDGET_H

#include <QWidget>

#include "httraqt.h"
#include "ui_ConfirmTab.h"

class HTTraQt;

class ConfirmTab: public QWidget, public Ui_ConfirmTab, public Translator
{
        Q_OBJECT
    public:
        ConfirmTab(QWidget *parent = 0, Qt::WindowFlags fl = 0);
        void translateTab();
        
private slots:
    void onRadio(bool t);

    private:
        HTTraQt* parent;
};

#endif
